@@ -10,7 +10,7 @@ class IAMController:
 
     @verify_credentials
     def new_account(self, handle):
-        res = requests.post(url=f'{self.account.hq}/account', json=dict(handle=handle), headers=self.account.headers)
+        res = requests.post(url=f'{self.account.hq}/iam/account', json=dict(handle=handle), headers=self.account.headers)
         if res.status_code != 200:
             raise Exception(res.text)
         cfg = self.account.read_keychain_config()
@@ -20,9 +20,16 @@ class IAMController:
         self.account.write_keychain_config(cfg)
         return res_json
 
+    @verify_credentials
+    def purge_account(self):
+        res = requests.delete(f'{self.account.hq}/iam/account', headers=self.account.headers)
+        if not res.status_code == 200:
+            raise Exception(res.text)
+        return res.text
+
     @verify_credentials
     def get_users(self):
-        res = requests.get(f'{self.account.hq}/account/user', headers=self.account.headers)
+        res = requests.get(f'{self.account.hq}/iam/user', headers=self.account.headers)
         if res.status_code == 200:
             return res.json()
         raise Exception(res.text)
@@ -30,7 +37,7 @@ class IAMController:
     @verify_credentials
     def create_user(self, permission, handle):
         res = requests.post(
-            url=f'{self.account.hq}/account/user',
+            url=f'{self.account.hq}/iam/user',
             json=dict(permission=permission, handle=handle),
             headers=self.account.headers
         )
@@ -40,14 +47,7 @@ class IAMController:
 
     @verify_credentials
     def delete_user(self, handle):
-        res = requests.delete(f'{self.account.hq}/account/user', json=dict(handle=handle), headers=self.account.headers)
+        res = requests.delete(f'{self.account.hq}/iam/user', json=dict(handle=handle), headers=self.account.headers)
         if res.status_code == 200:
             return True
         raise Exception(res.text)
-
-    @verify_credentials
-    def purge_account(self):
-        res = requests.delete(f'{self.account.hq}/account/purge', headers=self.account.headers)
-        if not res.status_code == 200:
-            raise Exception(res.text)
-        return res.text
